Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(945)

Unified Diff: media/base/pipeline.h

Issue 1526303004: Fix buffered range updates in media::Pipeline (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Added unit test Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/base/pipeline.h
diff --git a/media/base/pipeline.h b/media/base/pipeline.h
index 3ec8febf08ef8b80e34c10b6e0bbd0684d9869b8..6fd980bf32815ae7d0bc86f227ace2e560057938 100644
--- a/media/base/pipeline.h
+++ b/media/base/pipeline.h
@@ -245,8 +245,8 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
void FinishSeek();
// DemuxerHost implementaion.
- void AddBufferedTimeRange(base::TimeDelta start,
- base::TimeDelta end) override;
+ void OnBufferedTimeRangesChanged(
+ const Ranges<base::TimeDelta>& ranges) override;
void SetDuration(base::TimeDelta duration) override;
void OnDemuxerError(PipelineStatus error) override;
void AddTextStream(DemuxerStream* text_stream,
@@ -349,7 +349,7 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
// Amount of available buffered data as reported by |demuxer_|.
Ranges<base::TimeDelta> buffered_time_ranges_;
// True when AddBufferedTimeRange() has been called more recently than
// DidLoadingProgress().
wolenetz 2016/01/06 19:28:41 I'm not sure this has the same semantic meaning. I
servolk 2016/01/06 21:05:05 I assumed that the HTMLMediaElement 'progress' eve
@@ -349,7 +349,7 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
// Amount of available buffered data as reported by |demuxer_|.
Ranges<base::TimeDelta> buffered_time_ranges_;
- // True when AddBufferedTimeRange() has been called more recently than
+ // True when OnBufferedTimeRangesChanged() has been called more recently than
// DidLoadingProgress().
wolenetz 2016/01/06 19:28:41 I'm not sure this has the same semantic meaning. I
wolenetz 2016/01/14 19:25:53 Hmm. The spec also is more clear about when 'progr
bool did_loading_progress_;

Powered by Google App Engine
This is Rietveld 408576698